@@ -733,6 +733,74 @@ gboolean init_already_seen_hooks(TrayApplet *ta)
    return TRUE;
 }
 
+static void
+on_insert_text(GtkTextBuffer *buffer,
+	       GtkTextIter   *iter_end,
+	       gchar         *text,
+	       gint           arg3,
+	       gpointer       user_data)
+{
+   GtkTextIter iter, match_start, match_end, match_tmp, iter_real_end;
+   gboolean ret;
+
+   // get where we start
+   gtk_text_buffer_get_iter_at_offset(buffer, &iter,
+				      gtk_text_iter_get_offset(iter_end) - g_utf8_strlen(text,-1));
+   // search for http:// uris
+   while(gtk_text_iter_forward_search(&iter, 
+				      "http://",  GTK_TEXT_SEARCH_VISIBLE_ONLY, 
+				      &match_start, &match_end, iter_end))  {
+      match_tmp = match_end;
+      // we found a uri, iterate it until the end is found
+      while(gtk_text_iter_forward_char(&match_tmp)) {
+	 gchar *s = gtk_text_iter_get_text(&match_end,&match_tmp);
+	 if(strlen(s) < 1)
+	    break;
+	 char c = s[strlen(s)-1];
+	 if(c == ' ' || c == ')' || c == ']' || c == '\n' || c == '\t' || c == '>')
+	    break;
+	 match_end = match_tmp;
+      }
+      gchar *url = gtk_text_iter_get_text(&match_start, &match_end);
+      //g_print("url: '%s'\n",url);
+      GtkTextTag *tag;
+      tag = gtk_text_buffer_create_tag(buffer, NULL,
+				       "foreground","blue",
+				       "underline", PANGO_UNDERLINE_SINGLE,
+				       NULL);
+      g_object_set_data(G_OBJECT(tag), "url", url);
+      gtk_text_buffer_apply_tag(buffer, tag, &match_start, &match_end);
+      iter = match_end;
+   }
+}
+
+static void
+on_event_after(GtkWidget *widget,
+	       GdkEventButton  *event,
+	       gpointer   user_data)      
+{
+   if(event->type != GDK_BUTTON_RELEASE)
+      return;
+   if(event->button != 1)
+      return;
+   gint x,y;
+   gtk_text_view_window_to_buffer_coords(GTK_TEXT_VIEW(widget),
+					 GTK_TEXT_WINDOW_WIDGET,
+					 event->x, event->y,
+					 &x, &y);
+   GtkTextIter iter;
+   gtk_text_view_get_iter_at_location(GTK_TEXT_VIEW(widget), &iter, x, y);
+   GSList *tags = gtk_text_iter_get_tags(&iter);
+   for( ; tags != NULL ; tags = tags->next) {
+      gchar *url = g_object_get_data(G_OBJECT(tags->data), "url");
+      if(url != NULL) {
+	 //g_print("click: '%s'\n",url);
+	 char *argv[] = { "/usr/bin/gnome-open", url, NULL };
+	 g_spawn_async(NULL, argv, NULL, 0, NULL, NULL, NULL, NULL);
+	 break;
+      }
+   }
+}
 
 void hook_tray_icon_init(TrayApplet *ta)
 {
@@ -770,6 +838,10 @@ void hook_tray_icon_init(TrayApplet *ta)
 			       "scale", PANGO_SCALE_LARGE, 
 			       "weight", PANGO_WEIGHT_BOLD,
 			       NULL);  
+   g_signal_connect_after(G_OBJECT(buf), "insert-text", 
+			  G_CALLBACK(on_insert_text), NULL);
+   g_signal_connect_after(G_OBJECT(text), "event-after", 
+			  G_CALLBACK(on_event_after), NULL);
 
 
    /* read already seen hooks */
