@@ -58,6 +58,14 @@ static void tray_destroyed_cb(GtkWidget *widget, void *data);
 #define TIMEOUT_APT_RUN 120 /* 120 sec */
 
 
+void invoke(gchar *cmd, gchar *desktop, gboolean with_gksu)
+{
+   if(with_gksu)
+      invoke_with_gksu(cmd, desktop);
+   else
+      g_spawn_command_line_async(cmd, NULL);
+}
+
 void
 invoke_with_gksu(gchar *cmd, gchar *desktop)
 {
