@@ -11,14 +11,17 @@
 
 #define UPGRADE_CHECKER PACKAGE_LIB_DIR"/update-notifier/apt-check"
 
-char* actions[][3] = {
+// command, description, desktopfile, needs_gksu
+char* actions[][4] = {
    { "/usr/bin/update-manager", N_("Show updates"), 
-     "/usr/share/applications/update-manager.desktop" },
+     "/usr/share/applications/update-manager.desktop", FALSE },
+
    { "/usr/sbin/synaptic --dist-upgrade-mode --non-interactive --hide-main-window -o Synaptic::AskRelated=true",
-     N_("Install all updates"), "/usr/share/applications/synaptic.desktop" },
-   { "/usr/sbin/synaptic --update-at-startup --non-interactive --hide-main-window", N_("Check for updates"), "/usr/share/applications/synaptic.desktop" },
+     N_("Install all updates"), "/usr/share/applications/synaptic.desktop", TRUE
+ },
+   { "/usr/sbin/synaptic --update-at-startup --non-interactive --hide-main-window", N_("Check for updates"), "/usr/share/applications/synaptic.desktop", TRUE },
    { "/usr/sbin/synaptic", N_("Start package manager"), 
-     "/usr/share/applications/synaptic.desktop"},
+     "/usr/share/applications/synaptic.desktop", TRUE},
    { NULL, NULL, NULL }
 };
 
@@ -54,7 +57,7 @@ button_release_cb (GtkWidget *widget,
       if(last_launch.tv_sec == 0 || (current_time.tv_sec - last_launch.tv_sec > 2)) {
 	 last_launch.tv_sec = current_time.tv_sec;
 	 //g_print("%s %s\n",actions[index][0],actions[index][1]);
-	 invoke_with_gksu (actions[index][0], actions[index][2]);
+	 invoke (actions[index][0], actions[index][2], actions[index][3]);
       }
    }
    return TRUE;
